package
Version:
v0.0.0-...-91a168e
Opens a new window with list of versions in this module.
Published: Feb 19, 2026
License: MIT
Opens a new window with license information.
Imports: 2
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
type Proposal struct {
Type string `json:"type"`
Target string `json:"target,omitempty"`
Summary string `json:"summary,omitempty"`
Payload map[string]any `json:"payload,omitempty"`
Raw map[string]interface{} `json:"raw,omitempty"`
}
Source Files
¶
Directories
¶
|
|
|
plugins
|
|
|
|
|
|
|
|
|
|
|
|
|
|
Click to show internal directories.
Click to hide internal directories.